<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package thereader
 */

if ( ! function_exists( 'thereader_posted_on' ) ) :
	/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
	function thereader_posted_on() {
		global $post;

		$byline = sprintf(
			esc_html_x( '%s', 'post author', 'thereader' ),
			'<span class="author vcard" itemprop="author" itemscope itemtype="https://schema.org/Person"><span itemprop="name">by <a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span></span>'
		);
			thereader_post_categories_tags();

			$date = '';
		if ( is_single() ) {

			$date = esc_html__( ' - on ','thereader' ) . get_the_date( 'M j, Y' );

		}
			echo '  <span class="byline"> ' . $byline . $date . '</span>'; // WPCS: XSS OK.

	}
endif;

function thereader_post_categories_tags() {
	global $post;

	$taxonomies = get_object_taxonomies( (object) array(
		'post_type' => $post->post_type,
		'public' => true,
		'_builtin' => true,
	) );
	$taxonomy_category = '';
	$terms = get_the_terms( $post->ID, $taxonomies[0] );
	$sep = "<span class='hr'>/</span>";
	$i = 0;
	if ( ! empty( $terms ) ) {
		//if(!empty($terms)){
		foreach ( $terms as $term ) {
			if ( $i == ( count( $terms ) - 1) ) {
				$sep = '';
			} elseif ( $i == ( count( $terms ) - 2) ) {
				$sep = __( ' <span class="hr">/</span> ','thereader' );
			}
			$term_link = get_term_link( $term, $taxonomies[0] );
			if ( is_wp_error( $term_link ) ) {
				continue;
			}
			$taxonomy_category .= '<a href="' . esc_url( $term_link ) . '">' . esc_html( $term->name ) . '</a>' . $sep;
			$i++;
		}

		 echo '<span class="cate">' . esc_html__( 'Published in','thereader' ) . ' ' . wp_kses( $taxonomy_category, wp_kses_allowed_html( 'post' ) ) . '</span>';
		echo '</span>';
	}

}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function thereader_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'thereader_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'thereader_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so thereader_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so thereader_categorized_blog should return false.
		return false;
	}
}
