<?php
/* Popular post widget class  */
class Thereader_Widget_Popular_Posts extends WP_Widget {


	function __construct() {
		$widget_ops = array(
			'classname' => 'widget_popular_posts',
			'description' => __( 'Your site&#8217;s most popular Posts.','thereader' ),
		);
		parent::__construct( 'Thereader_Widget_Popular_Posts', __( 'T &rarr; Popular Posts','thereader' ), $widget_ops );
		$this->alt_option_name = 'widget_per_cat_popular_posts';
	}

	function widget( $args, $instance ) {
		$cache = wp_cache_get( 'widget_popular_entries', 'widget' );

		if ( ! is_array( $cache ) ) {
			$cache = array();
		}

		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract( $args );

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Popular Posts','thereader' );
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 8;
		$excerpt_length = ( ! empty( $instance['excerpt_length'] ) ) ? absint( $instance['excerpt_length'] ) : 10;
		$popular_per = 'comments';
		$post_type = 'post';
		$view = empty( $instance['view'] ) ? 'list' : apply_filters( 'widget_show_view', $instance['view'] );

		if ( $view == 'grid' ) { $class = 'grid';
		} else { $class = 'list'; }
		if ( ! $number ) {
			 $number = 10;
		}
		$show_excerpt = isset( $instance['show_excerpt'] ) ? $instance['show_excerpt'] : false;

		/* popular posts query */
		$r = new WP_Query( array(
			'post_type' => $post_type,
			'orderby' => 'comment_count',
			'order' => 'DESC',
			'posts_per_page' => $number,
			'no_found_rows' => true,
			'post_status' => 'publish',
		) ); /* Query to fetch per comments count  */

		/* Loop start */
		global $post;
		if ( $r->have_posts() ) :

			echo wp_kses( $args['before_widget'], wp_kses_allowed_html( 'post' ) ); ?>
		<?php if ( $title ) {
			echo wp_kses( $args['before_title'], wp_kses_allowed_html( 'post' ) );
			echo esc_html( $title );
			echo wp_kses( $args['after_title'], wp_kses_allowed_html( 'post' ) );
}?>
		<ul class="<?php echo $view; ?> row">
		<?php
		/* Loop to display popular posts */
		while ( $r->have_posts() ) : $r->the_post();
			$post_rel_img = thereader_get_image_withinfo( $post->ID,'popular-post-thumb' );
			$post_rel_img = $post_rel_img[0]['file'];
		?>
		
			<li class="main-view clearfix">
				<div class="view-img">
					<a href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>">
					<?php
					if ( has_post_thumbnail() ) {?>
							<img class="thumb-img"  src="<?php esc_url( the_post_thumbnail_url( 'thereader_post_small_size' ) );?>" alt="<?php esc_attr( get_the_title( $post->ID ) ); ?>" title="<?php the_title(); ?>"  /> 
						<?php
					} else {
						?>
						<img class="thumb-img"  src="<?php echo esc_url( get_template_directory_uri() . '/images/noimage.jpg' );?>" alt="<?php esc_attr( get_the_title( $post->ID ) ); ?>" title="<?php esc_attr( the_title() ); ?>"  /> 
						<?php
					}
						?>
						</a>
				</div>
				<div class="view-desc">
					<h4><a href="<?php esc_url( the_permalink() ); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a></h4>
					<p class="meta"><?php thereader_post_categories_tags(); ?> <span class="hr">/</span> <span class="byline"><?php echo get_the_time( get_option( 'date_format' ) ); ?></span></p>
					<?php if ( $show_excerpt ) : ?>
						<div class="post-excerpt"><?php threader_print_excerpt( $excerpt_length ); ?></div>
					<?php endif; ?>
				</div>
			</li>

			
		<?php endwhile; ?>
		</ul>
		<?php echo wp_kses( $args['after_widget'], wp_kses_allowed_html( 'post' ) );  ?>
		<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();
		else :
			echo '<p>';
			esc_html_e( 'No Popular posts.','thereader' );
			echo '</p>';
		endif;
		/* Loop End */
	}

	function update( $new_instance, $old_instance ) {
		return $new_instance;
	}



	function form( $instance ) {

		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$excerpt_length    = isset( $instance['excerpt_length'] ) ? absint( $instance['excerpt_length'] ) : 10;
		$show_excerpt = isset( $instance['show_excerpt'] ) ? (bool) $instance['show_excerpt'] : false;
		$popular_per = isset( $instance['popular_per'] ) ? esc_attr( $instance['popular_per'] ) : 'comments';
		$post_type = isset( $instance['post_type'] ) ? esc_attr( $instance['post_type'] ) : 'post';
		$view = strip_tags( @$instance['view'] );
			?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title','thereader' ); ?>: </label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_html( $title ); ?>" /></p>

				<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php esc_html_e( 'Number of posts to show','thereader' ); ?>: </label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo intval( $number ); ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox" <?php checked( $show_excerpt ); ?> id="<?php echo $this->get_field_id( 'show_excerpt' ); ?>" name="<?php echo $this->get_field_name( 'show_excerpt' ); ?>" />
		
		  <label for="<?php echo $this->get_field_id( 'show_excerpt' ); ?>"><?php esc_html_e( 'Display post excerpt?','thereader' ); ?></label></p>

				  <p><label for="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"><?php esc_html_e( 'Excerpt Length','thereader' ); ?>: </label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'excerpt_length' ); ?>" name="<?php echo $this->get_field_name( 'excerpt_length' ); ?>" type="text" value="<?php echo intval( $excerpt_length ); ?>" /></p>


		 <!-- Select post type option in back end -->
		 <p>
			 <label for="<?php echo $this->get_field_id( 'view' );  ?>"><?php esc_html_e( 'Select view','thereader' ); ?>: </label>
			 <select class="widefat" name="<?php echo $this->get_field_name( 'view' ); ?>" id="<?php  echo $this->get_field_id( 'view' ); ?>" >
				 <option value="list" <?php if ( $view == 'list' ) { echo 'selected=selected'; }?>><?php esc_html_e( 'List','thereader' ); ?></option>
				 <option value="grid" <?php if ( $view == 'grid' ) { echo 'selected=selected'; }?>><?php esc_html_e( 'Grid','thereader' ); ?></option>
			 </select>
		 </p>
		
	<?php
	}
}
?>
